<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Zgadnij</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Znaleziono</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normalne</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Duże</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Przeoczonych</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Koniec gry</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 of %n punkt</numerusform>
            <numerusform>%1 of %n punkty</numerusform>
            <numerusform>%1 of %n punktów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 z %n punktu</numerusform>
            <numerusform>3 z %n punktów</numerusform>
            <numerusform>3 z %n punktów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 z %n punktu</numerusform>
            <numerusform>2 z %n punktów</numerusform>
            <numerusform>2 z %n punktów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 z %n punktu</numerusform>
            <numerusform>1 z %n punktów</numerusform>
            <numerusform>1 z %n punktów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 z %n punktu</numerusform>
            <numerusform>0 z %n punktów</numerusform>
            <numerusform>0 z %n punktów</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punkt</numerusform>
            <numerusform>%n punkty</numerusform>
            <numerusform>%n punktów</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Maksymalny wynik obliczono z następujących trzydziestu słów:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n próba</numerusform>
            <numerusform>%n próby</numerusform>
            <numerusform>%n prób</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n błąd</numerusform>
            <numerusform>%n błędy</numerusform>
            <numerusform>%n błędów</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasyczne</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Napełnij</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Kondycja</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Kara</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Przydział</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Dyscyplina</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Odlicza 30 sekund i zwiększa przy prawidłowych próbach.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Odlicza 3 minuty.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Odlicza 30 sekund i napełnia przy prawidłowych próbach.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Odlicza 45 sekund i wstrzymuje przy prawidłowych próbach.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Koniec gry po 3 błędnych próbach.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Koniec gry po 30 próbach.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Odlicza 30 sekund i zwiększa lub zmniejsza przy prawidłowych próbach.</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Bez limitu</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation>Gra kończy się, gdy wszystkie słowa zostaną znalezione.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Nie można odczytać kości z pliku.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Nie można odczytać listy słów z pliku.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Język planszy</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Własny</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Wybierz...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Uwaga:&lt;/b&gt; Te ustawienia zostaną zastosowane po uruchomieniu nowej gry.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Kość:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Lista słów:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Słownik:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Wybierz plik kości</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Wybierz plik listy słów</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nowa gra</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Ilość słów:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Minimalna długość słowa:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niska</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Średnia</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Wysoka</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Losowo</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n litera</numerusform>
            <numerusform>%n litery</numerusform>
            <numerusform>%n liter</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Najlepsze wyniki</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Imię</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Ranga</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation>Maksimum</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Gratulacje!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Pobiłeś swój najlepszy wynik!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Dobra robota!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Masz nowy najlepszy wynik!</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>brak</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Wstrzymane&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Kliknij, aby wznowić grę.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Proszę czekać&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Ładowanie gry...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Kliknij, aby rozpocząć nową grę.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Proszę czekać&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Tworzenie nowej planszy...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Proszę czekać&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optymalizacja listy słów...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>&amp;Nowa gra...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Rzuć ponownie kośćmi</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Wybierz...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Podziel się...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Szczegóły</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Najlepsze wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Pokaż maksymalny wynik</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nigdy</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Koniec gry</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Zawsze</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Pokaż przeoczone &amp;słowa</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Pokaż &amp;liczbę słów</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Język &amp;planszy...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Sterowanie</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Prawo autorskie &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Wariant gry &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; dla jednego gracza</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Angielska lista słów oparta jest na &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; przez Kevina Atkinsona</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Hebrajska lista słów oparta jest na &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; przez Nadava Har&apos;Ela i Dana Kenigsberga</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importuj grę</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Gry Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Nie można uruchomić żądanej gry.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Eksportuj grę</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Zakończyć bieżącą grę?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Rozmiar planszy:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normalny</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Duży</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Gęstość słów:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Długość słów:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 lub więcej liter</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Rodzaj gry:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Sterowanie</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Sterowanie myszą:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wybór słowa:&lt;/b&gt; Kliknij na literę słowa.&lt;br&gt;&lt;b&gt;Zgadnij:&lt;/b&gt; Kliknij na ostatniej wybranej literze.&lt;br&gt;&lt;b&gt;Usuń litery:&lt;/b&gt; Kliknij na wcześniej wybranej literze.&lt;br&gt;&lt;b&gt;Wyczyść słowo:&lt;/b&gt; Kliknij dwa razy na pierwszą wybraną literę.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Sterowanie klawiaturą:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wybierz słowo:&lt;/b&gt; Wpisz litery słowa.&lt;br&gt;&lt;b&gt;Zgadnij:&lt;/b&gt; Naciśnij klawisz Enter.&lt;br&gt;&lt;b&gt;Wyczyść słowo:&lt;/b&gt; Naciśnij Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Litery:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Znaleziono:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punkt</numerusform>
            <numerusform>%n punkty</numerusform>
            <numerusform>%n punktów</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Gra wyszukiwania słów</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Plik gry.</translation>
    </message>
</context>
</TS>
